import * as path from 'path';
import * as fs from 'fs';

import express, { Request, Response } from 'express';
import morgan from 'morgan';
import cors from 'cors';

import bodyParser from 'body-parser';
import { BSON } from 'bson';

const corsOptions = {
    // 一些旧版浏览器（如 IE11、各种 SmartTV）在 204 状态下会有问题
    optionsSuccessStatus: 200
};

const app = express();

app.use(express.json());
app.use(cors(corsOptions));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: true }));
app.use(morgan('dev'));

// 测试项目部署请看 README.md
const rootPath = '../digital-vcd-render/public';

app.get('/', (req: Request, res: Response) => {
    res.send('<h1>Hello, World!</h1><br><img src="https://picx.zhimg.com/v2-b4251de7d2499e942c7ebf447a90d2eb_l.jpg"/>');
});

app.post('/save-view', async (req: Request, res: Response) => {    
    try {
        const { file, payload } = req.body;        
        const savePath = path.join(rootPath, file);
        const buffer = BSON.serialize(payload);
        fs.writeFileSync(savePath, buffer);
        res.send('success');
    } catch (error) {
        console.log('error happen in /save-view, ' + error);
        res.send('error');
    }
})

const PORT = process.env.PORT || 3000;
app.listen(PORT, () => {
    console.log(`Server is running on port ${PORT}`);
});